@@ -1,7 +1,7 @@
 import boto3
 from datetime import datetime
 import os
-
+from telegram import CallbackQuery
 from configparser import ConfigParser
 
 config = ConfigParser()
@@ -56,7 +56,9 @@ def write_voice(update, context, bucket, folder):
                     )
 
 def write(update, context, bucket, folder):
-    if update.message.voice:
+    if type(update)==CallbackQuery:
+        pass
+    elif update.message.voice:
         write_voice(update, context, bucket, folder)
     elif update.message.text:
         write_message(update, context, bucket, folder)
